@@ -6,9 +6,10 @@
 #include <QDesktopServices>
 #include <QtNetwork>
 #include <QTimer>
-#include "currency.h"
 #include "about.h"
 #include "help.h"
+#include "currencysettings.h"
+#include "unitsettings.h"
 
 namespace Ui {
     class MainWindow;
@@ -22,32 +23,44 @@ public:
 
 protected:
     void changeEvent(QEvent *e);
+    bool eventFilter(QObject *obj, QEvent *ev);
 
 private:
     Ui::MainWindow *ui;
     QSettings mvSettings;
     QXmlStreamReader xml;
-    Currency *currencyDialog;
     About *aboutDialog;
     Help *helpDialog;
+    CurrencySettings *currencySettings;
+    UnitSettings *unitSettings;
+
     double mvTotal;
     int mvAction;
     bool mvClear;
     bool mvUpdated;
+    int mvCurrencyPreset;
+    int mvUnitPreset;
+    bool mvCurrency;
 
     void updateValue(int actionType);
     void updateScreen(int valueType);
     void convertCurrency(QString fromCurrency, QString toCurrency);
+    void convertUnit(QString fromUnit, QString toUnit);
     void updateCurrency();
-    void updateButtons();
+
     void initialSettings();
 
 private slots:
-    void on_pushButton_Update_clicked();
+    void on_actionUnit_triggered();
+    void on_pushButton_Negate_clicked();
+    void on_pushButton_NextUnit_clicked();
+    void updateButtons();
+    void on_pushButton_NextCurrency_clicked();
+    void on_actionUpdate_triggered();
+    void on_actionCurrency_triggered();
     void on_actionDonate_triggered();
     void on_actionAbout_triggered();
     void on_actionHelp_triggered();
-    void on_pushButton_SetCurrency_clicked();
     void on_pushButton_Currency2_clicked();
     void on_pushButton_Currency1_clicked();
     void on_pushButton_Enter_clicked();
